==> exo.jcr.component.ext-1.11-sources.jar: org/exoplatform/services/jcr/ext/replication/async/transport/ExportChangesPacket.java <==
/*
 * Copyright (C) 2003-2008 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 */
package org.exoplatform.services.jcr.ext.replication.async.transport;

/**
 * Created by The eXo Platform SAS
 * 
 * @author <a href="karpenko.sergiy@gmail.com">Karpenko Sergiy</a>
 * @version $Id: ExportChangesPacket.java 111 2008-11-11 11:11:11Z serg $
 */
public class ExportChangesPacket extends ChangesPacket {

  public ExportChangesPacket(int type,
                             int priority,
                             byte[] crc,
                             long timeStamp,
                             int fileCount,
                             long offset,
                             byte[] buffer) {
    super(type, priority, crc, timeStamp, fileCount, offset, buffer);
  }

  /**
   * ExportChangesPacket constructor.
   * 
   */
  public ExportChangesPacket() {
    super();
  }

}

==> exo.jcr.component.ext-1.11.1-sources.jar: org/exoplatform/services/jcr/ext/replication/async/transport/ExportChangesPacket.java <==
/*
 * Copyright (C) 2003-2008 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 */
package org.exoplatform.services.jcr.ext.replication.async.transport;

/**
 * Created by The eXo Platform SAS
 * 
 * @author <a href="karpenko.sergiy@gmail.com">Karpenko Sergiy</a>
 * @version $Id: ExportChangesPacket.java 111 2008-11-11 11:11:11Z serg $
 */
public class ExportChangesPacket extends ChangesPacket {

  public ExportChangesPacket(int type,
                             int priority,
                             long totalPacketsCount,
                             byte[] crc,
                             long timeStamp,
                             int fileCount,
                             long offset,
                             byte[] buffer) {
    super(type, priority, totalPacketsCount, crc, timeStamp, fileCount, offset, buffer);
  }

  /**
   * ExportChangesPacket constructor.
   * 
   */
  public ExportChangesPacket() {
    super();
  }

}
